Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS License Manager.

Actions, resources, and condition keys for AWS License Manager - Service Authorization Reference

# Actions, resources, and condition keys for AWS License Manager

AWS License Manager (service prefix: `license-manager` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS License Manager
- Resource types defined by AWS License Manager
- Condition keys for AWS License Manager

## Actions defined by AWS License Manager

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AcceptGrant | Grants permission to accept a grant | Write | grant* |  |
CheckInLicense | Grants permission to check in license entitlements back to pool | Write |  |  |
CheckoutBorrowLicense | Grants permission to check out license entitlements for borrow use case | Write | license* |  |
CheckoutLicense | Grants permission to check out license entitlements | Write |  |  |
CreateGrant | Grants permission to create a new grant for license | Write | license* |  |
CreateGrantVersion | Grants permission to create new version of grant | Write | grant* |  |
CreateLicense | Grants permission to create a new license | Write |  |  |
CreateLicenseConfiguration | Grants permission to create a new license configuration | Tagging |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateLicenseVersion | Grants permission to create new version of license. | Write | license* |  |
CreateToken | Grants permission to create a new token for license | Write | license* |  |
DeleteGrant | Deletes a grant | Write | grant* |  |
DeleteLicense | Grants permission to delete a license | Write | license* |  |
DeleteLicenseConfiguration | Grants permission to permanently delete a license configuration | Write | license-configuration* |  |
DeleteToken | Grants permission to delete token | Write |  |  |
ExtendLicenseConsumption | Grants permission to extend consumption period of already checkout license entitlements | Write |  |  |
GetAccessToken | Grants permission to get access token | Read |  |  |
GetGrant | Grants permission to get a grant | Read | grant* |  |
GetLicense | Grants permission to get a license | Read | license* |  |
GetLicenseConfiguration | Grants permission to get a license configuration | List | license-configuration* |  |
GetLicenseUsage | Grants permission to get a license usage | Read | license* |  |
GetServiceSettings | Grants permission to get service settings | List |  |  |
ListAssociationsForLicenseConfiguration | Grants permission to list associations for a selected license configuration | List | license-configuration* |  |
ListDistributedGrants | Grants permission to list distributed grants | List |  |  |
ListFailuresForLicenseConfigurationOperations | Grants permission to list the license configuration operations that failed | List | license-configuration* |  |
ListLicenseConfigurations | Grants permission to list license configurations | List |  |  |
ListLicenseSpecificationsForResource | Grants permission to list license specifications associated with a selected resource | List |  |  |
ListLicenseVersions | Grants permission to list license versions | List | license* |  |
ListLicenses | Grants permission to list licenses | List |  |  |
ListReceivedGrants | Grants permission to list received grants | List |  |  |
ListReceivedLicenses | Grants permission to list received licenses | List |  |  |
ListResourceInventory | Grants permission to list resource inventory | List |  |  |
ListTagsForResource | Grants permission to list tags for a selected resource | List | license-configuration* |  |
ListTokens | Grants permission to list tokens | List |  |  |
ListUsageForLicenseConfiguration | Grants permission to list usage records for selected license configuration | List | license-configuration* |  |
RejectGrant | Grants permission to reject a grant | Write | grant* |  |
TagResource | Grants permission to tag a selected resource | Tagging | license-configuration* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to untag a selected resource | Tagging | license-configuration* |  |
UpdateLicenseConfiguration | Grants permission to update an existing license configuration | Write | license-configuration* |  |
UpdateLicenseSpecificationsForResource | Grants permission to updates license specifications for a selected resource | Write | license-configuration* |  |
UpdateServiceSettings | Grants permission to updates service settings | Permissions management |  |  |

## Resource types defined by AWS License Manager

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
license-configuration | `arn:$ { Partition}:license-manager:$ { Region}:$ { Account}:license-configuration/$ { LicenseConfigurationId}` | license-manager:ResourceTag/${TagKey}
license | `arn:$ { Partition}:license-manager::$ { Account}:license:$ { LicenseId}` |
grant | `arn:$ { Partition}:license-manager::$ { Account}:grant:$ { GrantId}` |

## Condition keys for AWS License Manager

AWS License Manager defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters create requests based on allowed set of values for each of the mandatory tags | String
aws:TagKeys | Enforce tag keys that are used in the request | String
license-manager:ResourceTag/${TagKey} | Filters actions based on tag-value associated with the resource. | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.